============
Installation
============

.. contents::
   :local:

You can install adc-streaming either via pip, conda, or from source.

To install with pip:

.. code:: bash

   pip install adc


To install with conda, you must use the channel from the SCiMMA Anaconda organization:

.. code:: bash

    conda install --channel scimma adc

To install from source:

.. code:: bash

    tar -xzf adc-x.y.z.tar.gz
    cd adc-x.y.z
    python setup.py install
